@@ -4,18 +4,16 @@
  *  SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
-#ifndef AKONADI_COLLECTIONCOLORATTRIBUTE_H
-#define AKONADI_COLLECTIONCOLORATTRIBUTE_H
+#pragma once
 
 #include "akonadicore_export.h"
 
-#include <attribute.h>
+#include "attribute.h"
 
 #include <QColor>
 
 namespace Akonadi
 {
-
 /**
  * @short Attribute that stores colors of a collection.
  *
@@ -47,4 +45,3 @@ private:
 
 } // namespace Akonadi
 
-#endif
